(* $Id: godi_pkglist.mli 977 2012-06-03 15:39:06Z gerd $ *)

(* Access to package lists *)

type pkg =
    { pkg_source : string;        (* Source symbol (see below) *)
      pkg_name : string;          (* Primary key *)
      pkg_version : string;       (* Version incl. package revision suffix *)
      pkg_comment : string;
      pkg_descr : string;
      pkg_maintainer : string;
      pkg_homepage : string;
      pkg_svn_path : string;      (* Relative path in SVN *)
      pkg_svn_rev : int option;   (* The SVN revision or None = deleted *)
      pkg_date : float;           (* Last release *)
      pkg_rel_by : string;        (* Release by whom (user ID) *)
      pkg_section : string;       (* GODI section *)
      pkg_distfiles : string list;      (* Current distfiles *)
    }

(* Source symbols:
   - public_<website>_<section> for official GODI sites, e.g. website=godirepo
   - custom_<customerid>_<section>

   This list does not include the URL(s) for the source, which must be
   otherwise given.
 *)


val read_packages_ini : string -> pkg list
  (* Reads the passed "packages.ini" file *)

val write_packages_ini : string -> pkg list -> unit
  (* Writes to the passed "packages.ini" file *)

val write_packages_ini_ch : out_channel -> pkg list -> unit
  (* Same, but the destination is an out_channel *)

val write_available_new : string -> pkg list -> unit
  (* Writes to the passed "available.new" file *)

val write_available_new_ch : out_channel -> pkg list -> unit
  (* Same, but the destination is an out_channel *)

val merge_packages_ini : keep_only_newest:bool -> pkg list list -> pkg list
  (* [merge_packages_ini pkglist_list]: merges the package lists and
     emits the combined list. If keep_only_newest, the emitted list
     - only includes the newest package if there are several versions of
       a package
     - sets a package to "deleted" if the latest update is a delete
       (i.e. for the latest package version there must be a delete entry)

     If not keep_only_newest, the emitted list contains all inputs. Only
     duplicates are removed.

     "Newer" means here that a package has a newer release date (pkg_date).
     We do not interpret the version string here.
   *)

val newest_package : ignore_deleted:bool -> pkg list -> string -> pkg option
  (* [newest_package pkglist name]: returns the newest package with the
     given name. If ignore_deleted, the newest package is also returned
     if it is marked as deleted. Otherwise, for deleted packages None is
     returned. If the package is not found at all, None is also returned

     "Newer" means here that a package has a newer release date (pkg_date).
     We do not interpret the version string here.
   *)

val build_tgz_name : pkg -> string
  (* Returns the name of the build.tgz file for this package
     (w/o path)
   *)

val legacy_build_tgz_name : pkg -> string
  (* The name of older build.tgz files (pre godi-tools-3, e.g. from an
     old bootstrap). It is essentially missing the pkg_source prefix.

     This name is also still used for build.tgz files on servers.
   *)

